<?php
/** Default**/
define('THEME_URL', get_template_directory_uri());
define('TEMPLATE_DIR', get_template_directory());
define("BI", THEME_URL . '/assets/img/bg/breadcrumb_bg.jpg');
$logo = wp_get_attachment_image_src(get_theme_mod('custom_logo'), 'full');
define('LU', ($logo) ? $logo[0] : THEME_URL . '/assets/img/logo/logo.png');

/**
 * COCHAGU functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package COCHAGU
 */

if (!defined('_S_VERSION')) {
    // Replace the version number of the theme on each release.
    define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function cochagu_setup()
{
    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on COCHAGU, use a find and replace
     * to change 'cochagu' to the name of your theme in all the template files.
     */
    load_theme_textdomain('cochagu', get_template_directory() . '/languages');

    // Add default posts and comments RSS feed links to head.
    add_theme_support('automatic-feed-links');

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support('title-tag');

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support('post-thumbnails');

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus(
        array(
            'menu-1' => esc_html__('Primary', 'cochagu'),
            'menu-2' => esc_html__('Footer Menu', 'destination'),
            'menu-3' => esc_html__('Quick Links', 'destination'),
        )
    );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support(
        'html5',
        array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
        )
    );

    // Set up the WordPress core custom background feature.
    add_theme_support(
        'custom-background',
        apply_filters(
            'cochagu_custom_background_args',
            array(
                'default-color' => 'ffffff',
                'default-image' => '',
            )
        )
    );

    // Add theme support for selective refresh for widgets.
    add_theme_support('customize-selective-refresh-widgets');

    /**
     * Add support for core custom logo.
     *
     * @link https://codex.wordpress.org/Theme_Logo
     */
    add_theme_support(
        'custom-logo',
        array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        )
    );
}
add_action('after_setup_theme', 'cochagu_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function cochagu_content_width()
{
    $GLOBALS['content_width'] = apply_filters('cochagu_content_width', 640);
}
add_action('after_setup_theme', 'cochagu_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function cochagu_widgets_init()
{
    register_sidebar(
        array(
            'name' => esc_html__('Sidebar', 'cochagu'),
            'id' => 'sidebar-1',
            'description' => esc_html__('Add widgets here.', 'cochagu'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget' => '</section>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        )
    );
}
add_action('widgets_init', 'cochagu_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function cochagu_scripts()
{
    wp_enqueue_style('cochagu-boot', THEME_URL . '/assets/css/bootstrap.min.css');
    wp_enqueue_style('cochagu-anim', THEME_URL . '/assets/css/animate.min.css');
    wp_enqueue_style('cochagu-mp', THEME_URL . '/assets/css/magnific-popup.css');
    wp_enqueue_style('cochagu-fa', THEME_URL . '/assets/css/fontawesome-all.min.css');
    wp_enqueue_style('cochagu-flaticon', THEME_URL . '/assets/css/flaticon.css');
    wp_enqueue_style('cochagu-odo', THEME_URL . '/assets/css/odometer.css');
    wp_enqueue_style('cochagu-jara', THEME_URL . '/assets/css/jarallax.css');
    wp_enqueue_style('cochagu-sb', THEME_URL . '/assets/css/swiper-bundle.min.css');
    wp_enqueue_style('cochagu-slick', THEME_URL . '/assets/css/slick.css');
    wp_enqueue_style('cochagu-aos', THEME_URL . '/assets/css/aos.css');
    wp_enqueue_style('cochagu-deg', THEME_URL . '/assets/css/default.css');
    wp_enqueue_style('cochagu-main', THEME_URL . '/assets/css/style.css');
    wp_enqueue_style('cochagu-boot', THEME_URL . '/assets/css/bootstrap.min.css');

    wp_enqueue_style('cochagu-style', get_stylesheet_uri(), array(), _S_VERSION);
    wp_style_add_data('cochagu-style', 'rtl', 'replace');

    wp_enqueue_script('cochagu-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
    wp_enqueue_script('cochagu-js-boot', THEME_URL . '/assets/js/bootstrap.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-mp', THEME_URL . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-om', THEME_URL . '/assets/js/jquery.odometer.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-appear', THEME_URL . '/assets/js/jquery.appear.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-gsap', THEME_URL . '/assets/js/gsap.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-st', THEME_URL . '/assets/js/ScrollTrigger.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-split', THEME_URL . '/assets/js/SplitText.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-gsapa', THEME_URL . '/assets/js/gsap-animation.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-jl', THEME_URL . '/assets/js/jarallax.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-pl', THEME_URL . '/assets/js/jquery.parallaxScroll.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-inview', THEME_URL . '/assets/js/jquery.inview.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-sb', THEME_URL . '/assets/js/swiper-bundle.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-slick', THEME_URL . '/assets/js/slick.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-aos', THEME_URL . '/assets/js/aos.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-wow', THEME_URL . '/assets/js/wow.min.js', array('jquery'), _S_VERSION, true);
    wp_enqueue_script('cochagu-js-main', THEME_URL . '/assets/js/main.js', array('jquery'), _S_VERSION, true);

}
add_action('wp_enqueue_scripts', 'cochagu_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

require TEMPLATE_DIR . '/inc/cpt.php';
require TEMPLATE_DIR . '/inc/cc.php';
add_action('customize_register', 'gd_new_customizer');

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Custom Functions
 */
require TEMPLATE_DIR . '/inc/cf.php';
